==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Block/ts/Block_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Block</name>
    <message>
        <location filename="../Block.js" line="+67"/>
        <source>Block Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show block tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Block</source>
        <translation>块(&amp;B)</translation>
    </message>
</context>
<context>
    <name>BlockDialog</name>
    <message>
        <location filename="../BlockDialog.js" line="+115"/>
        <source>Leading or trailing spaces.</source>
        <translation>前导或尾随空格。</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is empty.</source>
        <translation>块名为空。</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is invalid.</source>
        <translation>块名无效。</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Block &apos;%1&apos; already exists&lt;br&gt;and will be overwritten.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block already exists.</source>
        <translation>块名已经存在。</translation>
    </message>
    <message>
        <location filename="../BlockDialog.ui" line="+17"/>
        <source>Block Data</source>
        <translation>块数据</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Block name:</source>
        <translation>块名：</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>block 1</source>
        <translation>块1</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Block/ts/Block_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Block</name>
    <message>
        <location filename="../Block.js" line="+67"/>
        <source>Block Tools</source>
        <translation>块工具</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show block tools</source>
        <translation>显示块工具</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Block</source>
        <translation>块(&amp;B)</translation>
    </message>
</context>
<context>
    <name>BlockDialog</name>
    <message>
        <location filename="../BlockDialog.js" line="+134"/>
        <source>Leading or trailing spaces.</source>
        <translation>前导或尾随空格。</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is empty.</source>
        <translation>块名为空。</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is invalid.</source>
        <translation>块名无效。</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Block &apos;%1&apos; already exists&lt;br&gt;and will be overwritten.</source>
        <translation>&apos;%1&apos; 块已经存在，并将被覆盖。</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block already exists.</source>
        <translation>块名已经存在。</translation>
    </message>
    <message>
        <location filename="../BlockDialog.ui" line="+17"/>
        <source>Block Data</source>
        <translation>块数据</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Block name:</source>
        <translation>块名：</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>block 1</source>
        <translation>块1</translation>
    </message>
</context>
<context>
    <name>LayoutDialog</name>
    <message>
        <source>Leading or trailing spaces.</source>
        <translation type="obsolete">前导或尾随空格。</translation>
    </message>
</context>
</TS>
